@@ -139,6 +139,8 @@ void Export2DB::createTables() const {
 
         if (!exists(ways().addSchema())) {
             Xaction.exec(ways().create());
+            Xaction.exec("CREATE INDEX ON "+ ways().addSchema() + "  USING btree (source)");
+            Xaction.exec("CREATE INDEX ON "+ ways().addSchema() + "  USING btree (target)");
             std::cout << "TABLE: " << ways().addSchema() << " created ... OK.\n";
         }
 
@@ -269,7 +271,6 @@ Export2DB::export_osm(
 
 #endif
 
-    size_t count = 0;
     try {
 
 
@@ -284,8 +285,6 @@ Export2DB::export_osm(
         for (auto it = values.begin(); it != values.end(); ++it) {
             auto str = *it;
 
-            ++count;
-
             PQputline(mycon, str.c_str());
         }
 
@@ -302,9 +301,12 @@ Export2DB::export_osm(
                 }
                 return;
             }
-            size_t inc = values.size() / 2;
-            export_osm(std::vector<std::string>(values.begin(), values.begin() + inc), table);
-            export_osm(std::vector<std::string>(values.begin() + inc , values.end()), table);
+
+            const int64_t inc = values.size() / 2;
+            std::vector<std::string> first(values.begin(), values.begin() + inc);
+            std::vector<std::string> second(values.begin() + inc, values.end());
+            export_osm(first, table);
+            export_osm(second, table);
             return;
         };
 
@@ -337,13 +339,42 @@ void Export2DB::fill_vertices_table(
             ") , "
             " data1 AS (SELECT osm_id, lon, lat FROM (SELECT DISTINCT * FROM osm_vertex) a "
             ") "
-            " INSERT INTO " + vertices_tab + " (osm_id, lon, lat, the_geom) (SELECT data1.*, ST_SetSRID(ST_Point(lon, lat), 4326) FROM data1)");
+            " INSERT INTO " + vertices_tab + " (osm_id, geom) (SELECT osm_id, ST_SetSRID(ST_Point(lon, lat), 4326) FROM data1);");
+
     auto result = Xaction.exec(sql);
 
     std::cout << "\t Vertices inserted: " << result.affected_rows();
 }
 
 
+void Export2DB::fill_adjacent_edges(
+        const std::string &table,
+        const std::string &vertices_tab,
+        pqxx::work &Xaction) const {
+  std::string sql (
+      "WITH "
+      " a AS ("
+      "  SELECT v.id, array_agg(e.id) as outs FROM " + vertices_tab + " AS v join " + table + " AS e "
+      "  ON (v.id = source) where  cost > 0 GROUP BY v.id)"
+      "UPDATE " + vertices_tab + " AS v SET out_edges = outs FROM a WHERE v.id = a.id;");
+
+    auto result = Xaction.exec(sql);
+    std::cout << "\t out_edges modified: " << result.affected_rows();
+
+    sql =
+      "WITH "
+      " the_ins AS ("
+      "  SELECT v.id, array_agg(e.id) as ins FROM " + vertices_tab + " AS v join " + table + " AS e "
+      "  ON (v.id = target) where  reverse_cost > 0 GROUP BY v.id)"
+      "UPDATE " + vertices_tab + " AS v SET in_edges = ins FROM the_ins AS a WHERE v.id = a.id;";
+
+    result = Xaction.exec(sql);
+    std::cout << "\t in_edges modified: " << result.affected_rows();
+}
+
+
+
+
 
 
 
@@ -366,18 +397,21 @@ void Export2DB::fill_source_target(
             " WHERE w.target IS NULL and w.target_osm = v.osm_id;");
     Xaction.exec(sql2);
 
+    sql2 = " UPDATE " + table + " SET  length_m = ST_length(geography(geom)) WHERE length_m IS NULL;";
+    Xaction.exec(sql2);
+
     std::string sql3(
             " UPDATE " + table +
-            " SET  length_m = ST_length(geography(ST_Transform(the_geom, 4326))),"
+            " SET  "
             "      cost_s = CASE "
-            "           WHEN one_way = -1 THEN -ST_length(geography(ST_Transform(the_geom, 4326))) / (maxspeed_forward::float * 5.0 / 18.0)"
-            "           ELSE ST_length(geography(ST_Transform(the_geom, 4326))) / (maxspeed_backward::float * 5.0 / 18.0)"
+            "           WHEN one_way = -1 THEN -ST_length(geography(ST_Transform(geom, 4326))) / (maxspeed_forward::float * 5.0 / 18.0)"
+            "           ELSE ST_length(geography(ST_Transform(geom, 4326))) / (maxspeed_backward::float * 5.0 / 18.0)"
             "             END, "
             "      reverse_cost_s = CASE "
-            "           WHEN one_way = 1 THEN -ST_length(geography(ST_Transform(the_geom, 4326))) / (maxspeed_backward::float * 5.0 / 18.0)"
-            "           ELSE ST_length(geography(ST_Transform(the_geom, 4326))) / (maxspeed_backward::float * 5.0 / 18.0)"
+            "           WHEN one_way = 1 THEN -ST_length(geography(ST_Transform(geom, 4326))) / (maxspeed_backward::float * 5.0 / 18.0)"
+            "           ELSE ST_length(geography(ST_Transform(geom, 4326))) / (maxspeed_backward::float * 5.0 / 18.0)"
             "             END "
-            " WHERE length_m IS NULL AND maxspeed_backward !=0 AND maxspeed_forward != 0;");
+            " WHERE maxspeed_backward !=0 AND maxspeed_forward != 0;");
     Xaction.exec(sql3);
 }
 
@@ -400,7 +434,6 @@ void Export2DB::exportWays(const Ways &ways, const Configuration &config) const
     std::string copy_sql( "COPY " + temp_table + " (" + comma_separated(columns) + ") FROM STDIN");
 
 
-    int64_t split_count = 0;
     int64_t count = 0;
     size_t start = 0;
     auto it = ways.begin();
@@ -436,7 +469,6 @@ void Export2DB::exportWays(const Ways &ways, const Configuration &config) const
                 common_values.push_back(TO_STR(config.priority(way.tag_config())));
 
                 auto splits = way.split_me();
-                split_count +=  splits.size();
                 for (size_t j = 0; j < splits.size(); ++j) {
                     auto length = way.length_str(splits[j]);
 
@@ -490,7 +522,9 @@ void Export2DB::process_section(const std::string &ways_columns, pqxx::work &Xac
     //  std::cout << "Creating indices in temporary table\n";
     auto temp_table(ways().temp_name());
 
-    Xaction.exec("CREATE INDEX "+ temp_table + "_gdx ON "+ temp_table + " using gist(the_geom);");
+    Xaction.exec("CREATE INDEX "+ temp_table + "_gdx ON "+ temp_table + " using gist(geom);");
+    Xaction.exec("CREATE INDEX ON "+ temp_table + "  USING btree (source)");
+    Xaction.exec("CREATE INDEX ON "+ temp_table + "  USING btree (target)");
     Xaction.exec("CREATE INDEX ON "+ temp_table + "  USING btree (source_osm)");
     Xaction.exec("CREATE INDEX ON "+ temp_table + "  USING btree (target_osm)");
 
@@ -501,7 +535,7 @@ void Export2DB::process_section(const std::string &ways_columns, pqxx::work &Xac
     std::string delete_from_temp(
             " DELETE FROM "+ temp_table + " a "
             "     USING " + ways().addSchema() + " b "
-            "     WHERE a.the_geom ~= b.the_geom AND ST_OrderingEquals(a.the_geom, b.the_geom);");
+            "     WHERE a.geom ~= b.geom AND ST_OrderingEquals(a.geom, b.geom);");
     Xaction.exec(delete_from_temp);
 
     //  std::cout << "Updating to existing toplology the temporary table\n";
@@ -521,6 +555,7 @@ void Export2DB::process_section(const std::string &ways_columns, pqxx::work &Xac
             " (SELECT " + ways_columns + ", source, target, length_m, cost_s, reverse_cost_s FROM " + temp_table + "); ");
     auto result = Xaction.exec(insert_into_ways);
     std::cout << "\tSplit ways inserted " << result.affected_rows() << "\n";
+    fill_adjacent_edges(ways().addSchema(), vertices().addSchema(), Xaction);
 }
 
 
@@ -583,14 +618,12 @@ void Export2DB::createFKeys() const {
     /*
      * vertices
      */
-    execute(vertices().primary_key("id"));
     execute(vertices().unique("osm_id"));
     execute(vertices().gist_index());
 
     /*
      * Ways
      */
-    execute(ways().primary_key("gid"));
     execute(ways().foreign_key("source", vertices(), "id"));
     execute(ways().foreign_key("target", vertices(), "id"));
     execute(ways().foreign_key("source_osm", vertices(), "osm_id"));
@@ -686,7 +719,7 @@ void Export2DB::process_pois() const {
     execute(
             "\n WITH "
             "\n base AS ("
-            "\n     SELECT pid, w.id AS wid, w.the_geom AS wgeom, p.the_geom AS pgeom"
+            "\n     SELECT pid, w.id AS wid, w.geom AS wgeom, p.geom AS pgeom"
             "\n     FROM " + pois().addSchema() + " AS p JOIN " + ways().addSchema() + " AS w ON (edge_id = w.id)"
             + "\n     WHERE edge_id IS not NULL"
             + "\n ),"
